@@ -9,7 +9,7 @@ use vars qw(
 require Exporter;
 
 @ISA     = qw(Exporter);
-$VERSION = '0.02';
+$VERSION = '0.03';
 @EXPORT  = qw(
   &cardinal2alpha
   &ordinal2alpha
@@ -104,7 +104,7 @@ sub cardinal2alpha {
         #Dealing with the part off the block(s) of three 
         my $extra_digits = substr( $num, int( ( $len - 1 ) / 3 ) * 3 );
         $extra_digits = reverse($extra_digits);
-        push ( @result, &triple_digit_handling($extra_digits) )
+        push ( @result, triple_digit_handling($extra_digits) )
           unless $extra_digits == 1;
 
         #Adding name for the quantifier
@@ -145,14 +145,14 @@ sub cardinal2alpha {
     }    #end while len > 3
 
     if ( $len <= 3 ) {
-        push ( @result, &triple_digit_handling($num) );
+        push ( @result, triple_digit_handling($num) );
         return "@result";
     }
 }
 
 
 #This function takes an integer (scalar) as a parameter, which is
-#a 2- or 3-digit number, and returns a string (array), which is 
+#a 3-digit number or less, and returns a string (array), which is 
 #its Bask equivalent.
 #
 sub triple_digit_handling {
@@ -170,7 +170,7 @@ sub triple_digit_handling {
     #Handling 2-digit numbers
     if ( $len == 2 ) {
         ( $tens, $units ) = split ( //, sprintf( "%02d", $num ) );
-        @result = &double_digit_handling( $tens, $units );
+        @result = double_digit_handling( $tens, $units );
         return @result;
     }
 
@@ -183,7 +183,7 @@ sub triple_digit_handling {
             push ( @result, "eta" ) if $tens || $units;
         }
 
-        @tens_n_units = &double_digit_handling( $tens, $units );
+        @tens_n_units = double_digit_handling( $tens, $units );
         push ( @result, @tens_n_units );
         return @result;
     }
@@ -235,15 +235,14 @@ sub ordinal2alpha {
     return undef if ( $num < 0 || $num > 999_999_999_999 );
     return "lehenengo" if $num == 1;
 
-    push ( @result, join ( '', &cardinal2alpha($num), "garren" ) );
+    push ( @result, join ( '', cardinal2alpha($num), "garren" ) );
     return "@result";
 }
 
 1;
 __END__
 
-
-
+=pod
 
 =head1 NAME
 
@@ -252,40 +251,38 @@ Lingua::EU::Numbers - Converts numbers into Bask (Euskara).
 =head1 SYNOPSIS
 
   # Functional interface 
-  use Lingua::FR::Numbers;
-  my $number = shift ;
-  print "The cardinal value of $number is " . &cardinal2alpha($number) . " in Euskara.\n";
-  print "The ordinal value of $number is " . &ordinal2alpha($number) . " in Euskara.\n";
+  use Lingua::EU::Numbers;
+  my $number = shift;
+  print "The cardinal value of $number is " . cardinal2alpha($number) . " in Euskara.\n";
+  print "The ordinal value of $number is " . ordinal2alpha($number) . " in Euskara.\n";
 
 =head1 DESCRIPTION
 
-This module converts numbers (cardinals and ordinals) into their Bask
-(Euskara) equivalents. It accepts positive integers up to 1 trillion
-(excluded). Incidentally, the Bask counting system is vigesimal 
-(base 20).
+This module converts numbers (cardinals and ordinals) into their Bask (Euskara)
+equivalents.  It accepts positive integers up to, but not including, 1 trillion.
+Incidentally, the Bask counting system is vigesimal, i.e. base 20.
 
-The module uses unified Bask (Euskara Batua), which sometimes varies
-from the Bask spoken in the seven Bask provinces, especially from
-Labourd (Lapurdi) in the Northen Bask Country (Ipar Euskal 
-Herria). However, Euskara Batua is the official Bask taught in Bask 
-schools (Ikastolak) throughout the seven provinces.
+The module uses unified Bask (Euskara Batua), which sometimes varies from the
+Bask spoken in the seven Bask provinces, especially from Labourd (Lapurdi) in
+the Northen Bask Country (Ipar Euskal Herria).  However, Euskara Batua is the
+official Bask taught in Bask schools (Ikastolak) throughout the seven
+provinces.
 
-For example, the cardinal '18' is 'hemezortzi' in Euskara Batua, while
-it is 'hamazortzi' in Lapurdi. Those who wish to use their own version
-of Euskara can export %num2alpha and modify it at their own discretion.
+For example, the cardinal '18' is 'hemezortzi' in Euskara Batua, while it is
+'hamazortzi' in Lapurdi.  Those who wish to use their own version of Euskara can
+export %num2alpha and modify it at their own discretion.
 
 A Bask legend says that even the Devil did not succeed in learning this
-fascinating and truly unique language, but that should not deter you
-from doing so! Euskara is an orphan language of mysterious origins, 
-apparently unrelated to any language anywhere else in the world. It is
-believed to predate the Indo-European invasion and if so, this is one of 
-the world's most ancient languages.
+truly unique language, but that should not deter you from doing
+so.  Euskara is an orphan language of mysterious origins, apparently unrelated
+to any language anywhere else in the world.  It is believed to predate the
+Indo-European invasion and if so, this is one of the world's most ancient
+languages.
 
-The Basques refer to themselves as Euskaldunak, or 'speakers of the
-Euskara'. Being part of the Bask Nation is a question of language, not
-ethnicity or place of birth. There is not even a word for 'being a Bask'
-in Euskara. So if you learn this fascinating language, you too can
-become Euskaldun.
+Bask people refer to themselves as Euskaldunak, or 'speakers of the Euskara'.  
+Being part of the Bask Nation is a question of language, not ethnicity or place
+of birth.  There is not even a word for 'being a Bask' in Euskara.  So if you
+learn this fascinating language, you too can become Euskaldun.
 
 =head1 FUNCTIONS
 
@@ -293,53 +290,52 @@ become Euskaldun.
 
 =item cardinal2alpha($number)
 
-This function accepts an integer (scalar) as a parameter and
-returns a string (array), which is its Bask cardinal equivalent.
+This function accepts an integer (scalar) as a parameter and returns a string
+(array), which is its Bask cardinal equivalent.
 
-It returns C<undef> if: a)the argument passed is not defined, or: b)the
-argument is not an integer, or: c)the integer passed does not fall
-between zero and 999,999,999,999.
+It returns C<undef> if a)the argument passed is not defined, or b)the
+argument is not an integer, or c)the integer passed does not fall between zero
+and 999,999,999,999.
 
 =item ordinal2alpha($number)
 
-This function accepts an integer (scalar) as a parameter and
-returns a string (array), which is its Bask ordinal equivalent.
+This function accepts an integer (scalar) as a parameter and returns a string
+(array), which is its Bask ordinal equivalent.
 
-It returns C<undef> if: a)the argument passed is not defined, or: b)the
-argument is not an integer, or: c)the integer passed does not fall
-between zero and 999,999,999,999.
+It returns C<undef> if a)the argument passed is not defined, or b)the
+argument is not an integer, or c)the integer passed does not fall between zero
+and 999,999,999,999.
 
 =back
 
 =head1 EXPORT
 
-This module exports by default the functions &cardinal2alpha() and
-&ordinal2alpha(). It can also export the hash %num2alpha.
+This module exports by default the functions cardinal2alpha() and
+ordinal2alpha().  It can also export the hash %num2alpha.
 
 =head1 SOURCE
 
 The Bask encyclopedia "Administrazio-hizkeraren entziklopedia" and its
 web pages referring to Bask numbers (cardinals and ordinals) at:
-http://www.ivap.com/eusk/entziklo/kardinal.htm and
-http://www.ivap.com/eusk/entziklo/ordinal.htm
+http://www.ivap.com/eusk/entziklo/kardinal.htm and http://www.ivap.com/eusk/entziklo/ordinal.htm.
 
 =head1 BUGS AND COMMENTS
 
 If you find one, please use the Request Tracker Interface -
 http://rt.cpan.org/NoAuth/Bugs.html?Dist=Lingua-EU-Numbers to report
-it. Esker anitz!
+it. 
 
 =head1 SEE ALSO
 
-Lingua::FR::Numbers
+Lingua::FR::Numbers, Lingua::Num2Word
 
 =head1 THANKS 
 
-Milesker to Briac Pilpr who gave me the idea for this module, and who
-also thought about exporting the hash %num2alpha for people wanting to
-use their own version of Euskara.
+Milesker to Briac Pilpr who gave me the idea for this module, and who also
+thought about exporting the hash %num2alpha for people wanting to use their own
+version of Euskara.
 
-Esker asko to Deric Gerlach who reviewed my English and my overall pod 
+Esker asko to Deric Gerlach who reviewed my English and my overall pod
 documentation.
 
 =head1 AUTHOR
@@ -350,8 +346,8 @@ Isabelle Hernandez, <isabelle@cpan.org>
 
 Copyright 2002 by Isabelle Hernandez
 
-This library is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This library is free software; you can redistribute it and/or modify it under
+the same terms as Perl itself.
 
 =cut
 
